@@ -8,8 +8,9 @@ import sys
 
 # Codee Junaid 
 
+import inforion.ionapi.model.inforlogin as inforlogin
+
 
-from inforion.ionapi.basic import load_config,login,header
 from inforion.transformation.transform import tranform_data
 from inforion.ionapi.controller import *
 from inforion.ionapi.model import * 
@@ -22,25 +23,27 @@ import os.path
 
 
 def main_load(url=None,ionfile=None,program=None,method=None,dataframe=None,outputfile=None,start=None,end=None):
-        
+     
+    
     if validators.url(url) != True:
         return ("Error: URL is not valid")
     
     if os.path.exists(ionfile) == False:
         return ("Error: File does not exist")
     else:
-        config = load_config(ionfile)
+        config = inforlogin.load_config(ionfile)
+        
+
     
     result = spliturl(url)
 
     if "Call" in result:
         if len(result["Call"]) > 0:
             if result["Call"] == "execute":
-
-                config = load_config(ionfile)
-                token=login(url,config)
+                config = inforlogin.load_config(ionfile)
+                token =  inforlogin.login()
                 
-                headers = header(config,token)
+                headers = inforlogin.header()
                 if "Bearer"  not in headers['Authorization']:
                     return "Error: InforION Login is not working"
                 if start is None or end is None:
@@ -51,26 +54,26 @@ def main_load(url=None,ionfile=None,program=None,method=None,dataframe=None,outp
                     
             if result["Call"] == "executeSnd":
 
-                config = load_config(ionfile)
-                token=login(url,config)
+                config = inforlogin.load_config(ionfile)
+                token = inforlogin.login()
                 
-                headers = header(config,token)
+                headers = inforlogin.header(token)
                 if "Bearer"  not in headers['Authorization']:
                     return "InforION Login is not working"
                 return executeSnd(url,headers,program,method,dataframe,outputfile,start,end)  
             if result["Call"] == "executeAsyncSnd":
         
-                config = load_config(ionfile)
-                token=login(url,config)
+                config = inforlogin.load_config(ionfile)
+                token= inforlogin.login()
                 
-                headers = header(config,token)
+                headers = inforlogin.header(token)
                 if "Bearer"  not in headers['Authorization']:
                     return "InforION Login is not working"
                 return executeAsyncSnd(url,headers,program,method,dataframe,outputfile,start,end)
 
     if method == "checklogin":
-        token=login(url,config)
-        headers = header(config,token)
+        token= inforlogin.login()
+        headers = inforlogin.header()
         return (headers['Authorization'])
 
 def main_transformation(mappingfile=None,mainsheet=None,stagingdata=None,outputfile=None):
