@@ -1,15 +1,16 @@
-import requests
+
+
+
+'''
+
+Not needed after testing it will deletetd 
+
 import base64
 import sys
 import os 
 import json
 
-import time
-import datetime
 
-from requests_oauthlib import OAuth2Session
-from requests.auth import HTTPBasicAuth
-from oauthlib.oauth2 import BackendApplicationClient
 
 
 from inforion.helper.dynamic import url_change
@@ -17,88 +18,12 @@ from inforion.helper.urlsplit import spliturl
 
 import inforion.ionapi.model.inforlogin as inforlogin
 
-def addSecs(tm, secs):
-    try:
-        if type(secs) != int:
-            secs = int(secs)
-        if secs > 3600:
-            fulldate = datetime.datetime(100, 1, 1, tm.hour, tm.minute, tm.second)
-            fulldate = fulldate + datetime.timedelta(seconds=3600)
-        else:
-            fulldate = datetime.datetime(100, 1, 1, tm.hour, tm.minute, tm.second)
-            fulldate = fulldate + datetime.timedelta(seconds=secs-400)
-        #fulldate = fulldate + datetime.timedelta(seconds=60)
-    except:
-        fulldate = datetime.datetime(100, 1, 1, tm.hour, tm.minute, tm.second)
-        fulldate = fulldate + datetime.timedelta(seconds=600)
-    return fulldate.time()
-
-def load_config(IONFile):
-    with open(IONFile) as json_file:
-        data = json.load(json_file)
-    return data 
-
-
-    
-
-
-def login(url,config):
-    
-    result = spliturl(url)
-
-    start_session = datetime.datetime.now().time()
-
-    #print (result)
-    base_url = url_change(url) 
-    #base_url = "https://mingle-sso.eu1.inforcloudsuite.com/"
-   
-    #base_url = base_url + "/" + result['Company']
-
-        #'https://mingle-sso.eu1.inforcloudsuite.com:443/BVB_DEV'
-
-    url = base_url + "/as/token.oauth2"
-    
-
-    data = {
-                'grant_type' : 'password',
-                'username' : config['saak'],
-                'password' : config['sask'],
-                'client_id' : config['ci'],
-                'client_secret' : config['cs'],
-                'scope' : '',
-                'redirect_uri' : 'https://localhost/'
-    }
-
-    #print (data)
-    r = requests.post(url, data=data)
-    
-    r = r.json()
-
-    access_token = r['access_token']
-    expires_in = r['expires_in']
-    refresh_token = r['refresh_token']
-    token_type = r['token_type']
-    saak = config['saak']
-    sask = config['sask']
-    client_id = config['ci']
-    client_secret = config['cs']
-  
-    session_expire = addSecs(start_session, expires_in)
-    #session_expire = addSecs(start_session, 60)  
-
-    
-    inforlogin.update(access_token, expires_in, refresh_token, token_type,start_session,session_expire,saak,sask,client_id,client_secret)
-
-    #print (r.status_code)
-    #print ("TEST")
-    #print (r.json())
-
-
-    return r
 
 
 
-def reconnect(url,headers):
+
+
+def reconnect2(url,headers):
     start_session = datetime.datetime.now().time()
 
 
@@ -123,8 +48,7 @@ def reconnect(url,headers):
     expires_in = inforlogin._GLOBAL_expires_in
 
     data = {
-                'grant_type' : 'refresh_token',
-                'refresh_token' : refresh_token,
+                'grant_type' : 'password',
                 'username' : saak,
                 'password' : sask,
                 'client_id' : client_id,
@@ -191,4 +115,6 @@ def header(config,token):
         'Authorization':        'Bearer ' +token['access_token'],
 
     }
-    return headers
\ No newline at end of file
+    return headers
+
+'''
\ No newline at end of file
